==> jc-1.4.0.tar.gz: java/lang/VMFloat.h <==
// final class java.lang.VMFloat

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8a4ea07ff88e78f8 java_lang_VMFloat

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMFloat_H_
#define _JC_java_lang_VMFloat_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_VMFloat$sub_refs	_jc_java_lang_VMFloat$sub_refs;
typedef struct _jc_java_lang_VMFloat$sub_nonrefs	_jc_java_lang_VMFloat$sub_nonrefs;
typedef struct _jc_java_lang_VMFloat$refs	_jc_java_lang_VMFloat$refs;
typedef struct _jc_java_lang_VMFloat$nonrefs	_jc_java_lang_VMFloat$nonrefs;
typedef struct _jc_java_lang_VMFloat$object	_jc_java_lang_VMFloat$object;

typedef const struct _jc_java_lang_VMFloat$vmethods	_jc_java_lang_VMFloat$vmethods;
typedef const struct _jc_java_lang_VMFloat$vtable	_jc_java_lang_VMFloat$vtable;
typedef const struct _jc_java_lang_VMFloat$vtype	_jc_java_lang_VMFloat$vtype;

// Constructors
extern void _jc_java_lang_VMFloat$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMFloat$object *);

// Static methods
extern void _jc_java_lang_VMFloat$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jint _jc_java_lang_VMFloat$method$floatToIntBits$8b96af62a8cd130d(_jc_env *, jfloat);
extern jint _jc_java_lang_VMFloat$method$floatToRawIntBits$c772408decb31ebb(_jc_env *, jfloat);
extern jfloat _jc_java_lang_VMFloat$method$intBitsToFloat$dbc520b5c53cb7dc(_jc_env *, jint);

// Virtual methods structure
struct _jc_java_lang_VMFloat$vmethods {
};

// Vtable
struct _jc_java_lang_VMFloat$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMFloat$vmethods	java_lang_VMFloat;
};

// Vtype
struct _jc_java_lang_VMFloat$vtype {
	_jc_type			type;
	_jc_java_lang_VMFloat$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMFloat$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMFloat$refs {
    _jc_java_lang_VMFloat$sub_refs	java_lang_VMFloat;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMFloat$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMFloat$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMFloat$sub_nonrefs	java_lang_VMFloat;
};

// Object instance structure
struct _jc_java_lang_VMFloat$object {
	_jc_java_lang_VMFloat$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMFloat$vtype	*vtype;
	_jc_java_lang_VMFloat$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMFloat$vtype _jc_java_lang_VMFloat$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMFloat, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMFloat$class_object;

#endif	/* _JC_java_lang_VMFloat_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMFloat.h <==
// final class java.lang.VMFloat

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8a4ea07ff88e78f8 java_lang_VMFloat

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMFloat_H_
#define _JC_java_lang_VMFloat_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_VMFloat$sub_refs	_jc_java_lang_VMFloat$sub_refs;
typedef struct _jc_java_lang_VMFloat$sub_nonrefs	_jc_java_lang_VMFloat$sub_nonrefs;
typedef struct _jc_java_lang_VMFloat$refs	_jc_java_lang_VMFloat$refs;
typedef struct _jc_java_lang_VMFloat$nonrefs	_jc_java_lang_VMFloat$nonrefs;
typedef struct _jc_java_lang_VMFloat$object	_jc_java_lang_VMFloat$object;

typedef const struct _jc_java_lang_VMFloat$vmethods	_jc_java_lang_VMFloat$vmethods;
typedef const struct _jc_java_lang_VMFloat$vtable	_jc_java_lang_VMFloat$vtable;
typedef const struct _jc_java_lang_VMFloat$vtype	_jc_java_lang_VMFloat$vtype;

// Constructors
extern void _jc_java_lang_VMFloat$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMFloat$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_VMFloat$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_VMFloat$method$floatToIntBits$8b96af62a8cd130d(_jc_env *, jfloat) _JC_JCNI_ATTR;
extern jint _jc_java_lang_VMFloat$method$floatToRawIntBits$c772408decb31ebb(_jc_env *, jfloat) _JC_JCNI_ATTR;
extern jfloat _jc_java_lang_VMFloat$method$intBitsToFloat$dbc520b5c53cb7dc(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMFloat$vmethods {
};

// Vtable
struct _jc_java_lang_VMFloat$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMFloat$vmethods	java_lang_VMFloat;
};

// Vtype
struct _jc_java_lang_VMFloat$vtype {
	_jc_type			type;
	_jc_java_lang_VMFloat$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMFloat$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMFloat$refs {
    _jc_java_lang_VMFloat$sub_refs	java_lang_VMFloat;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMFloat$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMFloat$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMFloat$sub_nonrefs	java_lang_VMFloat;
};

// Object instance structure
struct _jc_java_lang_VMFloat$object {
	_jc_java_lang_VMFloat$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMFloat$vtype	*vtype;
	_jc_java_lang_VMFloat$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMFloat$vtype _jc_java_lang_VMFloat$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMFloat, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMFloat$class_object;

#endif	/* _JC_java_lang_VMFloat_H_ */
